"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _tokenTypes = require("../tokenTypes");

var _border = _interopRequireDefault(require("./border"));

var _boxShadow = _interopRequireDefault(require("./boxShadow"));

var _flex = _interopRequireDefault(require("./flex"));

var _flexFlow = _interopRequireDefault(require("./flexFlow"));

var _font = _interopRequireDefault(require("./font"));

var _fontFamily = _interopRequireDefault(require("./fontFamily"));

var _placeContent = _interopRequireDefault(require("./placeContent"));

var _textDecoration = _interopRequireDefault(require("./textDecoration"));

var _textDecorationLine = _interopRequireDefault(require("./textDecorationLine"));

var _textShadow = _interopRequireDefault(require("./textShadow"));

var _transform = _interopRequireDefault(require("./transform"));

var _util = require("./util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var background = function background(tokenStream) {
  return {
    backgroundColor: tokenStream.expect(_tokenTypes.COLOR)
  };
};

var borderColor = (0, _util.directionFactory)({
  types: [_tokenTypes.COLOR],
  prefix: 'border',
  suffix: 'Color'
});
var borderRadius = (0, _util.directionFactory)({
  directions: ['TopLeft', 'TopRight', 'BottomRight', 'BottomLeft'],
  prefix: 'border',
  suffix: 'Radius'
});
var borderWidth = (0, _util.directionFactory)({
  prefix: 'border',
  suffix: 'Width'
});
var margin = (0, _util.directionFactory)({
  types: [_tokenTypes.LENGTH, _tokenTypes.UNSUPPORTED_LENGTH_UNIT, _tokenTypes.PERCENT, _tokenTypes.AUTO],
  prefix: 'margin'
});
var padding = (0, _util.directionFactory)({
  prefix: 'padding'
});

var fontVariant = function fontVariant(tokenStream) {
  return {
    fontVariant: [tokenStream.expect(_tokenTypes.IDENT)]
  };
};

var fontWeight = function fontWeight(tokenStream) {
  return {
    fontWeight: tokenStream.expect(_tokenTypes.WORD) // Also match numbers as strings

  };
};

var shadowOffset = function shadowOffset(tokenStream) {
  return {
    shadowOffset: (0, _util.parseShadowOffset)(tokenStream)
  };
};

var textShadowOffset = function textShadowOffset(tokenStream) {
  return {
    textShadowOffset: (0, _util.parseShadowOffset)(tokenStream)
  };
};

var _default = {
  background: background,
  border: _border["default"],
  borderColor: borderColor,
  borderRadius: borderRadius,
  borderWidth: borderWidth,
  boxShadow: _boxShadow["default"],
  flex: _flex["default"],
  flexFlow: _flexFlow["default"],
  font: _font["default"],
  fontFamily: _fontFamily["default"],
  fontVariant: fontVariant,
  fontWeight: fontWeight,
  margin: margin,
  padding: padding,
  placeContent: _placeContent["default"],
  shadowOffset: shadowOffset,
  textShadow: _textShadow["default"],
  textShadowOffset: textShadowOffset,
  textDecoration: _textDecoration["default"],
  textDecorationLine: _textDecorationLine["default"],
  transform: _transform["default"]
};
exports["default"] = _default;